import { h, Host, createEvent, getAssetPath, proxyCustomElement } from '@stencil/core/internal/client';

function api(url) {
    return fetch(url).then((response) => {
        if (!response.ok) {
            throw new Error(response.statusText);
        }
        const contentType = response.headers.get("Content-Type");
        if (/application\/json/.test(contentType)) {
            return response.json();
        }
        return response.text();
    });
}

const suggestions = new Map();
/** requests suggestions from url and caches responses */
const getSuggestions = (url) => {
    if (suggestions.has(url)) {
        return Promise.resolve(suggestions.get(url));
    }
    return api(url).then((response) => {
        suggestions.set(url, response);
        return response;
    });
};

let globalIdCounter = 0;
const getUniqueId = () => {
    globalIdCounter++;
    return `ux-unique-id-${globalIdCounter}`;
};

const autosuggestInputCss = ".ux-autosuggest-input{display:block;position:relative}.ux-autosuggest-input__input-container{position:relative}.ux-autosuggest-input__suggestions{padding-top:44px;position:absolute;z-index:1;width:100%;top:0;left:0;-webkit-box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);pointer-events:none}.ux-autosuggest-input__suggestions .ux-suggest-item{pointer-events:auto}.ux-autosuggest-input__suggestions--hidden{display:none}.ux-autosuggest-input__suggestion-link{text-decoration:none}.ux-autosuggest-input__suggestion-link:last-child .ux-suggest-item{border:0}";

class AutosuggestInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** placeholder text for input */
        this.placeholder = "";
        /** name attribute for input */
        this.name = "";
        /** id attribute for input. A unique id will be generated if this is empty */
        this.inputId = "";
        /** label for input */
        this.label = "";
        /** URL for autosuggest-API */
        this.url = "";
        this.suggestions = [];
        this.input = "";
        this.isHidden = true;
        this.id = "";
    }
    componentWillLoad() {
        const { inputId } = this;
        this.id = inputId || getUniqueId();
    }
    onInput(event) {
        if (this.url === "") {
            return;
        }
        const { value } = event.target;
        this.input = value;
        if (value === "") {
            this.suggestions = [];
            return;
        }
        getSuggestions(`${this.url}?q=${value}`)
            .then((response) => (this.suggestions = response))
            .catch((error) => console.error(error));
    }
    onBlur() {
        this.isHidden = true;
    }
    onFocus() {
        this.isHidden = false;
    }
    onClick(event, value) {
        event.preventDefault();
        const input = this.domNode.querySelector("input");
        input.value = value;
        this.suggestions = [];
    }
    render() {
        const baseClass = "ux-autosuggest-input";
        const { placeholder, name, suggestions, id, input, label, isHidden, } = this;
        return (h(Host, { class: baseClass, onFocusout: () => this.onBlur() }, label !== "" && (h("label", { class: "ux-label", htmlFor: id }, label)), h("div", { class: `${baseClass}__input-container` }, h("input", { class: "ux-input", name: name, type: "text", placeholder: placeholder, autocomplete: "off", autocapitalize: "off", id: id, onInput: (event) => this.onInput(event), onFocus: () => this.onFocus() }), h("div", { class: {
                [`${baseClass}__suggestions`]: true,
                [`${baseClass}__suggestions--hidden`]: isHidden,
            } }, suggestions === null || suggestions === void 0 ? void 0 : suggestions.map(({ value, description, image }) => (h("a", { class: `${baseClass}__suggestion-link`, href: "#", onFocus: () => this.onFocus(), onClick: (event) => this.onClick(event, value) }, h("ux-autosuggest-item", { text: value, input: input, subline: description, image: image }))))))));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "inputId": ["componentWillLoad"]
    }; }
    static get style() { return autosuggestInputCss; }
}

/** returns the matched part and the remaining part of the text */
const getSuggestionHighlight = (input, text) => {
    const firstPart = text.substring(0, input.length);
    if (firstPart.toLowerCase() !== input.toLowerCase()) {
        return ["", text];
    }
    const matchedString = firstPart;
    const remaining = text.substring(input.length);
    return [matchedString, remaining];
};

const autosuggestItemCss = ".ux-autosuggest-item{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;display:-ms-flexbox;display:flex;border-bottom:solid 1px #c4c4c4;color:#393939;background-color:#fff}.ux-autosuggest-item__image{width:75px;height:75px;background-size:cover;background-color:#e7e7e7}.ux-autosuggest-item__text-container{padding:15px}.ux-autosuggest-item__highlight{color:#bbd03a}.ux-autosuggest-item__subline{text-transform:uppercase}";

class AutosuggestItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** search query that will be highlighted in the text */
        this.input = "";
        /** suggestion text that matches the input */
        this.text = "";
        /** subline below the text */
        this.subline = "";
        /** optional image URL */
        this.image = "";
    }
    render() {
        const baseClass = "ux-autosuggest-item";
        const { text, subline, image, input } = this;
        const [highlight, remaining] = getSuggestionHighlight(input, text);
        return (h(Host, { class: baseClass }, image !== "" && (h("div", { class: `${baseClass}__image`, style: { backgroundImage: `url(${image})` } })), h("div", { class: `${baseClass}__text-container` }, h("div", { class: `${baseClass}__text` }, h("span", { class: `${baseClass}__highlight` }, highlight), remaining), h("div", { class: `${baseClass}__subline ux-text-tiny ux-text-tiny--bold` }, subline))));
    }
    static get style() { return autosuggestItemCss; }
}

const checkboxCss = ".ux-checkbox{display:inline-block;position:relative}.ux-checkbox--disabled{pointer-events:none}.ux-checkbox--disabled::before{content:\" \";display:block;position:absolute;width:100%;height:100%;left:0;top:0;background-color:rgba(255, 255, 255, 0.7);z-index:3}.ux-checkbox__wrapper{-ms-flex-align:center;align-items:center;cursor:pointer;display:-ms-inline-flexbox;display:inline-flex;position:relative;vertical-align:middle;width:100%;padding-bottom:10px}.ux-checkbox__input{opacity:0;position:absolute}.ux-checkbox__icon{background-position:center;background-repeat:no-repeat;display:inline-block;font-variant:normal;font-weight:normal;height:20px;line-height:1;speak:none;text-rendering:optimizeLegibility;text-transform:none;width:20px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}.ux-checkbox__icon--unchecked{background-image:url(\"data:image/svg+xml;charset%3DUS-ASCII,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2020%2020%22%20style%3D%22enable-background%3Anew%200%200%2020%2020%22%3E%3Cpath%20style%3D%22fill%3A%23010202%22%20d%3D%22M19%200H0v20h20V0h-1zm0%2019H1V1h18v18z%22%2F%3E%3C%2Fsvg%3E\")}.ux-checkbox__icon--checked{background-image:url(\"data:image/svg+xml;charset%3DUS-ASCII,%3Csvg%20data-name%3D%22Ebene%201%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2030%2030%22%3E%3Ctitle%3Echeckbox_checked%3C%2Ftitle%3E%3Cpath%20d%3D%22M29%200H0v30h30V0h-1zm-1%2028H2V2h26v26z%22%2F%3E%3Cpath%20d%3D%22M12.9%2019.91l1.05-1.04%208.88-8.89-1.04-1.04-8.89%208.88-4.18-4.18-1.04%201.05%204.18%204.18%201.04%201.04z%22%2F%3E%3C%2Fsvg%3E\")}.ux-checkbox__label{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;font-size:12px;line-height:20px;margin-left:10px;text-transform:uppercase}.ux-checkbox__input:not(:checked)~.ux-checkbox__icon--checked{display:none}.ux-checkbox__input:checked~.ux-checkbox__icon--unchecked{display:none}";

class Checkbox extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** value of the input element, not visible to the user */
        this.value = "";
        /** text inside the label element, visible to the user */
        this.label = "";
        /** name which is used for checkbox groups or as identifier in forms */
        this.name = "";
        /** indicates if the checkbox is checked */
        this.checked = false;
        /** indicates if the checkbox is disabled */
        this.disabled = false;
    }
    render() {
        const baseClass = "ux-checkbox";
        return (h(Host, { class: {
                [baseClass]: true,
                [`${baseClass}--disabled`]: this.disabled,
            } }, h("label", { class: `${baseClass}__wrapper` }, h("input", { class: `${baseClass}__input`, type: "checkbox", value: this.value, name: this.name, checked: this.checked, disabled: this.disabled }), h("span", { class: `${baseClass}__icon ${baseClass}__icon--unchecked` }), h("span", { class: `${baseClass}__icon ${baseClass}__icon--checked` }), h("span", { class: `${baseClass}__label` }, this.label, " ", h("slot", null)))));
    }
    static get style() { return checkboxCss; }
}

const checkboxListItemCss = ".ux-checkbox-list-item{display:block}";

class CheckboxListItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** name which is used for checkbox groups or as identifier in forms  */
        this.name = "";
        /** indicates if the checkbox is checked */
        this.checked = false;
        /** indicates if the checkbox is disabled */
        this.disabled = false;
    }
    render() {
        const baseClass = "ux-checkbox-list-item";
        return (h(Host, { class: baseClass }, h("ux-checkbox", { value: this.value, label: this.label, name: this.name, checked: this.checked, disabled: this.disabled }, h("slot", null))));
    }
    static get style() { return checkboxListItemCss; }
}

function copyToClipboard(generatedString) {
    const copyText = new Promise((resolve) => {
        if (navigator.clipboard != undefined) {
            // Modern browsers
            navigator.clipboard.writeText(generatedString).then(function () {
                resolve(true);
            }, function (err) {
                console.error("Could not copy text: ", err);
            });
        }
        else {
            // Internet Explorer
            const el = document.createElement("textarea");
            el.value = generatedString;
            document.body.appendChild(el);
            el.focus();
            el.select();
            document.execCommand("copy");
            document.body.removeChild(el);
            resolve(true);
        }
    });
    return copyText;
}

const copyToClipboardCss = ".ux-copy-to-clipboard{display:block}.ux-copy-to-clipboard__copy-area{position:relative;cursor:pointer}";

class CopyToClipboard extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Default icon */
        this.clickToCopyIcon = "documents";
        /** Icon shown after copy link was clicked */
        this.clickToCopyIconSuccessful = "checkmark-rounded-thin";
        /** Setting wether link to be copied is hidden */
        this.hideTextToCopy = false;
        this.wasSuccessful = false;
        this.clickHandler = (stringToCopy) => {
            copyToClipboard(stringToCopy)
                .then((response) => {
                this.wasSuccessful = response;
            })
                .catch(function (err) {
                console.log("Could not copy link:", err);
            });
            setTimeout(() => {
                this.wasSuccessful = false;
            }, 2000);
        };
    }
    render() {
        return (h(Host, { class: "ux-copy-to-clipboard" }, this.textToCopy && (h("div", { onClick: () => this.clickHandler(this.textToCopy) }, !this.hideTextToCopy && (h("div", { class: "ux-copy-to-clipboard__text-to-copy" }, this.textToCopy)), h("div", { class: "ux-copy-to-clipboard__copy-area" }, h("span", null, this.wasSuccessful
            ? this.clickToCopyMessageSuccessful
            : this.clickToCopyMessage), h("ux-icon", { name: this.wasSuccessful
                ? this.clickToCopyIconSuccessful
                : this.clickToCopyIcon }))))));
    }
    static get style() { return copyToClipboardCss; }
}

function getAttributes(element) {
    if (typeof element === "undefined")
        return {};
    const nodeMap = element.attributes;
    const length = nodeMap.length;
    return Object.keys(nodeMap).reduce((props, current) => {
        try {
            const numCurrent = parseInt(current);
            if (numCurrent < length) {
                const property = nodeMap[current];
                return Object.assign(Object.assign({}, props), { [property.name]: property.value });
            }
        }
        catch (err) {
            // nothing
        }
    }, {});
}

const filterObject = (originalObject, ignoreList) => Object.keys(originalObject)
    .filter((key) => !ignoreList.includes(key))
    .reduce((obj, key) => (Object.assign(Object.assign({}, obj), { [key]: originalObject[key] })), {});

const dataIngestCss = ".ux-data-ingest{display:block}";

/** these common HTML attributes will not be considered for fetching data */
const ignoreAttributeList = [
    "class",
    "id",
    "style",
    "slot",
    "tabindex",
    "title",
];
class DataIngest extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** contains the filtered attributes with their URLs */
        this.attributes = {};
        this.startRequest = createEvent(this, "uxStartRequest", 7);
    }
    componentWillLoad() {
        this.refreshAttributes();
        this.observer = new MutationObserver(() => this.refreshAttributes());
        this.observer.observe(this.host, {
            attributes: true,
            childList: false,
            subtree: false,
        });
    }
    disconnectedCallback() {
        this.observer.disconnect();
    }
    /** reads the attributes and their URLs and matches them with the previous ones */
    refreshAttributes() {
        const oldAttributes = this.attributes;
        this.attributes = filterObject(getAttributes(this.host), ignoreAttributeList);
        Object.keys(this.attributes).forEach((key) => {
            if (this.attributes[key] !== oldAttributes[key]) {
                this.loadData(key);
            }
        });
    }
    /** loads the data from the url supplied via attribute to put it onto the child element */
    loadData(attributeName) {
        const url = this.attributes[attributeName];
        if (url === "")
            return;
        this.startRequest.emit(attributeName);
        const child = this.host.firstElementChild;
        const loading = `${attributeName}Loading`;
        if (child === null) {
            return;
        }
        child[loading] = true;
        api(url)
            .then((result) => {
            child[loading] = false;
            child[attributeName] = result;
        })
            .catch(() => {
            child[loading] = false;
        });
    }
    render() {
        return (h(Host, { class: "ux-data-ingest" }, h("slot", null)));
    }
    get host() { return this; }
    static get style() { return dataIngestCss; }
}

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, basedir, module) {
	return module = {
	  path: basedir,
	  exports: {},
	  require: function (path, base) {
    return commonjsRequire();
  }
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var dayjs_min = createCommonjsModule(function (module, exports) {
!function(t,e){module.exports=e();}(commonjsGlobal,function(){var t="millisecond",e="second",n="minute",r="hour",i="day",s="week",u="month",o="quarter",a="year",h=/^(\d{4})-?(\d{1,2})-?(\d{0,2})[^0-9]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?.?(\d{1,3})?$/,f=/\[([^\]]+)]|Y{2,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,c=function(t,e,n){var r=String(t);return !r||r.length>=e?t:""+Array(e+1-r.length).join(n)+t},d={s:c,z:function(t){var e=-t.utcOffset(),n=Math.abs(e),r=Math.floor(n/60),i=n%60;return (e<=0?"+":"-")+c(r,2,"0")+":"+c(i,2,"0")},m:function(t,e){var n=12*(e.year()-t.year())+(e.month()-t.month()),r=t.clone().add(n,u),i=e-r<0,s=t.clone().add(n+(i?-1:1),u);return Number(-(n+(e-r)/(i?r-s:s-r))||0)},a:function(t){return t<0?Math.ceil(t)||0:Math.floor(t)},p:function(h){return {M:u,y:a,w:s,d:i,D:"date",h:r,m:n,s:e,ms:t,Q:o}[h]||String(h||"").toLowerCase().replace(/s$/,"")},u:function(t){return void 0===t}},$={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_")},l="en",m={};m[l]=$;var y=function(t){return t instanceof v},M=function(t,e,n){var r;if(!t)return l;if("string"==typeof t)m[t]&&(r=t),e&&(m[t]=e,r=t);else {var i=t.name;m[i]=t,r=i;}return !n&&r&&(l=r),r||!n&&l},g=function(t,e){if(y(t))return t.clone();var n="object"==typeof e?e:{};return n.date=t,n.args=arguments,new v(n)},D=d;D.l=M,D.i=y,D.w=function(t,e){return g(t,{locale:e.$L,utc:e.$u,$offset:e.$offset})};var v=function(){function c(t){this.$L=this.$L||M(t.locale,null,!0),this.parse(t);}var d=c.prototype;return d.parse=function(t){this.$d=function(t){var e=t.date,n=t.utc;if(null===e)return new Date(NaN);if(D.u(e))return new Date;if(e instanceof Date)return new Date(e);if("string"==typeof e&&!/Z$/i.test(e)){var r=e.match(h);if(r)return n?new Date(Date.UTC(r[1],r[2]-1,r[3]||1,r[4]||0,r[5]||0,r[6]||0,r[7]||0)):new Date(r[1],r[2]-1,r[3]||1,r[4]||0,r[5]||0,r[6]||0,r[7]||0)}return new Date(e)}(t),this.init();},d.init=function(){var t=this.$d;this.$y=t.getFullYear(),this.$M=t.getMonth(),this.$D=t.getDate(),this.$W=t.getDay(),this.$H=t.getHours(),this.$m=t.getMinutes(),this.$s=t.getSeconds(),this.$ms=t.getMilliseconds();},d.$utils=function(){return D},d.isValid=function(){return !("Invalid Date"===this.$d.toString())},d.isSame=function(t,e){var n=g(t);return this.startOf(e)<=n&&n<=this.endOf(e)},d.isAfter=function(t,e){return g(t)<this.startOf(e)},d.isBefore=function(t,e){return this.endOf(e)<g(t)},d.$g=function(t,e,n){return D.u(t)?this[e]:this.set(n,t)},d.year=function(t){return this.$g(t,"$y",a)},d.month=function(t){return this.$g(t,"$M",u)},d.day=function(t){return this.$g(t,"$W",i)},d.date=function(t){return this.$g(t,"$D","date")},d.hour=function(t){return this.$g(t,"$H",r)},d.minute=function(t){return this.$g(t,"$m",n)},d.second=function(t){return this.$g(t,"$s",e)},d.millisecond=function(e){return this.$g(e,"$ms",t)},d.unix=function(){return Math.floor(this.valueOf()/1e3)},d.valueOf=function(){return this.$d.getTime()},d.startOf=function(t,o){var h=this,f=!!D.u(o)||o,c=D.p(t),d=function(t,e){var n=D.w(h.$u?Date.UTC(h.$y,e,t):new Date(h.$y,e,t),h);return f?n:n.endOf(i)},$=function(t,e){return D.w(h.toDate()[t].apply(h.toDate("s"),(f?[0,0,0,0]:[23,59,59,999]).slice(e)),h)},l=this.$W,m=this.$M,y=this.$D,M="set"+(this.$u?"UTC":"");switch(c){case a:return f?d(1,0):d(31,11);case u:return f?d(1,m):d(0,m+1);case s:var g=this.$locale().weekStart||0,v=(l<g?l+7:l)-g;return d(f?y-v:y+(6-v),m);case i:case"date":return $(M+"Hours",0);case r:return $(M+"Minutes",1);case n:return $(M+"Seconds",2);case e:return $(M+"Milliseconds",3);default:return this.clone()}},d.endOf=function(t){return this.startOf(t,!1)},d.$set=function(s,o){var h,f=D.p(s),c="set"+(this.$u?"UTC":""),d=(h={},h[i]=c+"Date",h.date=c+"Date",h[u]=c+"Month",h[a]=c+"FullYear",h[r]=c+"Hours",h[n]=c+"Minutes",h[e]=c+"Seconds",h[t]=c+"Milliseconds",h)[f],$=f===i?this.$D+(o-this.$W):o;if(f===u||f===a){var l=this.clone().set("date",1);l.$d[d]($),l.init(),this.$d=l.set("date",Math.min(this.$D,l.daysInMonth())).toDate();}else d&&this.$d[d]($);return this.init(),this},d.set=function(t,e){return this.clone().$set(t,e)},d.get=function(t){return this[D.p(t)]()},d.add=function(t,o){var h,f=this;t=Number(t);var c=D.p(o),d=function(e){var n=g(f);return D.w(n.date(n.date()+Math.round(e*t)),f)};if(c===u)return this.set(u,this.$M+t);if(c===a)return this.set(a,this.$y+t);if(c===i)return d(1);if(c===s)return d(7);var $=(h={},h[n]=6e4,h[r]=36e5,h[e]=1e3,h)[c]||1,l=this.$d.getTime()+t*$;return D.w(l,this)},d.subtract=function(t,e){return this.add(-1*t,e)},d.format=function(t){var e=this;if(!this.isValid())return "Invalid Date";var n=t||"YYYY-MM-DDTHH:mm:ssZ",r=D.z(this),i=this.$locale(),s=this.$H,u=this.$m,o=this.$M,a=i.weekdays,h=i.months,c=function(t,r,i,s){return t&&(t[r]||t(e,n))||i[r].substr(0,s)},d=function(t){return D.s(s%12||12,t,"0")},$=i.meridiem||function(t,e,n){var r=t<12?"AM":"PM";return n?r.toLowerCase():r},l={YY:String(this.$y).slice(-2),YYYY:this.$y,M:o+1,MM:D.s(o+1,2,"0"),MMM:c(i.monthsShort,o,h,3),MMMM:c(h,o),D:this.$D,DD:D.s(this.$D,2,"0"),d:String(this.$W),dd:c(i.weekdaysMin,this.$W,a,2),ddd:c(i.weekdaysShort,this.$W,a,3),dddd:a[this.$W],H:String(s),HH:D.s(s,2,"0"),h:d(1),hh:d(2),a:$(s,u,!0),A:$(s,u,!1),m:String(u),mm:D.s(u,2,"0"),s:String(this.$s),ss:D.s(this.$s,2,"0"),SSS:D.s(this.$ms,3,"0"),Z:r};return n.replace(f,function(t,e){return e||l[t]||r.replace(":","")})},d.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},d.diff=function(t,h,f){var c,d=D.p(h),$=g(t),l=6e4*($.utcOffset()-this.utcOffset()),m=this-$,y=D.m(this,$);return y=(c={},c[a]=y/12,c[u]=y,c[o]=y/3,c[s]=(m-l)/6048e5,c[i]=(m-l)/864e5,c[r]=m/36e5,c[n]=m/6e4,c[e]=m/1e3,c)[d]||m,f?y:D.a(y)},d.daysInMonth=function(){return this.endOf(u).$D},d.$locale=function(){return m[this.$L]},d.locale=function(t,e){if(!t)return this.$L;var n=this.clone(),r=M(t,e,!0);return r&&(n.$L=r),n},d.clone=function(){return D.w(this.$d,this)},d.toDate=function(){return new Date(this.valueOf())},d.toJSON=function(){return this.isValid()?this.toISOString():null},d.toISOString=function(){return this.$d.toISOString()},d.toString=function(){return this.$d.toUTCString()},c}();return g.prototype=v.prototype,g.extend=function(t,e){return t(e,v,g),g},g.locale=M,g.isDayjs=y,g.unix=function(t){return g(1e3*t)},g.en=m[l],g.Ls=m,g});
});

var utc = createCommonjsModule(function (module, exports) {
!function(t,i){module.exports=i();}(commonjsGlobal,function(){return function(t,i,e){var s=(new Date).getTimezoneOffset(),n=i.prototype;e.utc=function(t){return new i({date:t,utc:!0,args:arguments})},n.utc=function(){return e(this.toDate(),{locale:this.$L,utc:!0})},n.local=function(){return e(this.toDate(),{locale:this.$L,utc:!1})};var u=n.parse;n.parse=function(t){t.utc&&(this.$u=!0),this.$utils().u(t.$offset)||(this.$offset=t.$offset),u.call(this,t);};var o=n.init;n.init=function(){if(this.$u){var t=this.$d;this.$y=t.getUTCFullYear(),this.$M=t.getUTCMonth(),this.$D=t.getUTCDate(),this.$W=t.getUTCDay(),this.$H=t.getUTCHours(),this.$m=t.getUTCMinutes(),this.$s=t.getUTCSeconds(),this.$ms=t.getUTCMilliseconds();}else o.call(this);};var f=n.utcOffset;n.utcOffset=function(t){var i=this.$utils().u;if(i(t))return this.$u?0:i(this.$offset)?f.call(this):this.$offset;var e,n=Math.abs(t)<=16?60*t:t;return 0!==t?(e=this.local().add(n+s,"minute")).$offset=n:e=this.utc(),e};var r=n.format;n.format=function(t){var i=t||(this.$u?"YYYY-MM-DDTHH:mm:ss[Z]":"");return r.call(this,i)},n.valueOf=function(){var t=this.$utils().u(this.$offset)?0:this.$offset+s;return this.$d.valueOf()-6e4*t},n.isUTC=function(){return !!this.$u},n.toISOString=function(){return this.toDate().toISOString()},n.toString=function(){return this.toDate().toUTCString()};var a=n.toDate;n.toDate=function(t){return "s"===t&&this.$offset?e(this.format("YYYY-MM-DD HH:mm:ss:SSS")).toDate():a.call(this)};}});
});

dayjs_min.extend(utc);
class DateTime extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** UTC time in a ISO_8601 Format https://en.wikipedia.org/wiki/ISO_8601 example: 2020-05-20 17:32:33 */
        this.utc = "";
        /** Format String according to https://day.js.org/docs/en/display/format example: "DD.MM.YYYY HH:mm". You can escape characters by wrapping them in []. For now this webcomponent displays localized parts in a date like "Monday" only in English */
        this.format = "";
        /** Holds the final result */
        this.formattedDateTime = "";
    }
    componentWillLoad() {
        const { utc, format } = this;
        if (utc === "" || format === "") {
            this.formattedDateTime = "";
            return;
        }
        const utcDate = dayjs_min.utc(utc);
        if (!utcDate.isValid()) {
            console.error(`ux-date-time received an invalid date. UTC: "${utc}"`);
            this.formattedDateTime = "";
            return;
        }
        this.formattedDateTime = utcDate.local().format(format);
    }
    render() {
        return h(Host, { class: "ux-date-time" }, this.formattedDateTime);
    }
    static get watchers() { return {
        "utc": ["componentWillLoad"],
        "format": ["componentWillLoad"]
    }; }
}

const dropdownCss = ".ux-dropdown{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;display:block;font-size:12px;position:relative;text-transform:uppercase}.ux-dropdown__label{-ms-flex-align:center;align-items:center;border:1px solid #131313;cursor:pointer;display:-ms-flexbox;display:flex;-ms-flex-pack:justify;justify-content:space-between;padding:13px 25px}.ux-dropdown__label svg{height:15px;-webkit-transform:rotate(0deg);transform:rotate(0deg);-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:15px}.ux-dropdown__dropdown-locator{position:absolute;z-index:1;top:calc(100% - 1px);-webkit-transform:scaleY(0);transform:scaleY(0);-webkit-transform-origin:top;transform-origin:top;-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:100%}.ux-dropdown__menu{background-color:#fff;border:1px solid #131313;border-top:0}.ux-dropdown__menu .ux-list__filter-input{border-right:0;border-left:0;margin-bottom:10px;padding-left:25px;padding-right:25px}.ux-dropdown__list>li{padding:0 25px}.ux-dropdown.ux-dropdown--down .ux-dropdown__label svg{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.ux-dropdown.ux-dropdown--down .ux-dropdown__dropdown-locator{-webkit-transform:scaleY(1);transform:scaleY(1)}";

class Dropdown extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.isOpen = false;
        /** Text displayed on the Dropdown */
        this.label = "";
        /** Name Identifies the dropdown in a bigger context (for example in forms, filters) */
        this.name = "";
        /** This toggles the text-input to filter the dropdown items */
        this.filterable = false;
    }
    handleBodyClick(event) {
        if (!this.domNode.contains(event.target)) {
            this.isOpen = false;
        }
    }
    onLabelClick() {
        this.isOpen = !this.isOpen;
    }
    render() {
        return (h(Host, { class: {
                "ux-dropdown": true,
                "ux-dropdown--down": this.isOpen,
            } }, h("span", { class: "ux-dropdown__label", onClick: this.onLabelClick.bind(this) }, this.label, h("ux-icon", { name: "arrow-down" })), h("div", { class: "ux-dropdown__dropdown-locator" }, h("ux-list", { filterable: this.filterable, class: "ux-dropdown__menu" }, h("slot", null)))));
    }
    get domNode() { return this; }
    static get style() { return dropdownCss; }
}

/**
 * Polyfill for Element APIs for IE11
 * from https://developer.mozilla.org/en-US/docs/Web/API/Element/closest#Polyfill
 */
const applyPolyfills = () => {
    if (!Element.prototype.matches) {
        Element.prototype.matches =
            Element.prototype.msMatchesSelector ||
                Element.prototype.webkitMatchesSelector;
    }
    if (!Element.prototype.closest) {
        Element.prototype.closest = function (s) {
            var el = this;
            do {
                if (Element.prototype.matches.call(el, s))
                    return el;
                el = el.parentElement || el.parentNode;
            } while (el !== null && el.nodeType === 1);
            return null;
        };
    }
};

const filterCss = ".ux-filter{display:block}";

applyPolyfills();
const referenceAttr = "data-reference";
class Filter extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.filterChange = createEvent(this, "uxFilterChange", 7);
    }
    tagRemovedHandler(event) {
        const checkbox = this.domNode.querySelector(`input[type="checkbox"][${referenceAttr}="${event.detail}"]`);
        if (checkbox !== null) {
            checkbox.checked = false;
            this.filterChange.emit();
        }
    }
    onChange(e) {
        const checkbox = e.target;
        if (!checkbox.matches('input[type="checkbox"]')) {
            return;
        }
        if (checkbox.matches(`:not(:checked)[${referenceAttr}]`)) {
            const reference = checkbox.getAttribute(referenceAttr);
            const tags = this.domNode.querySelectorAll(`ux-tag[reference="${reference}"]`);
            [].forEach.call(tags, (tag) => tag.remove());
        }
        else {
            this.addTag(checkbox);
        }
        this.filterChange.emit(e);
    }
    addTag(checkbox) {
        const reference = getUniqueId();
        checkbox.setAttribute(referenceAttr, reference);
        const labelText = checkbox.closest("label").innerText;
        const tagList = this.domNode.querySelector(".ux-tag-list");
        const tag = document.createElement("ux-tag");
        tag.setAttribute("reference", reference);
        tag.innerText = labelText;
        tagList.appendChild(tag);
    }
    componentDidLoad() {
        this.initFilters();
        this.initSlot();
    }
    initFilters() {
        if (typeof this.endpoint !== "string" || this.endpoint === "") {
            // TODO: uninit/reset
            return;
        }
        fetch(this.endpoint)
            .then((r) => r.json())
            .then((response) => {
            this.filterValues = response.filterValues;
            this.domNode.querySelectorAll("ux-dropdown").forEach((item) => {
                if (item.matches("[name]")) {
                    new Array(response.filterValues[item.getAttribute("name")]).forEach((filterValuesInfo) => {
                        // @ts-ignore
                        item.querySelector("ux-list").setFilterValues(filterValuesInfo);
                    });
                }
            });
        });
    }
    initSlot() {
        // check if web components in slot are correctly loaded
        // this is a workaround because of this bug: https://github.com/ionic-team/stencil/issues/1130
        if (this.domNode.querySelector(`ux-checkbox:not(.hydrated), ux-checkbox-list-item:not(.hydrated)`) !== null) {
            window.setTimeout(() => this.initSlot(), 50);
            return;
        }
        // init checkboxes that are checked at load
        const checkedCheckboxes = this.domNode.querySelectorAll(`input[type="checkbox"]:checked`);
        [].forEach.call(checkedCheckboxes, (checkbox) => this.addTag(checkbox));
    }
    render() {
        return (h(Host, { class: "ux-filter" }, h("form", { onSubmit: (e) => e.preventDefault(), onChange: (e) => this.onChange(e) }, h("slot", null))));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "endpoint": ["initFilters"]
    }; }
    static get style() { return filterCss; }
}

const isStr = (val) => typeof val === "string";

const validateContent = (svgContent) => {
    if (svgContent && typeof document !== "undefined") {
        const div = document.createElement("div");
        div.innerHTML = svgContent;
        // setup this way to ensure it works on IE
        for (let i = div.childNodes.length - 1; i >= 0; i--) {
            if (div.childNodes[i].nodeName.toLowerCase() !== "svg") {
                div.removeChild(div.childNodes[i]);
            }
        }
        // must only have 1 root element
        const svgElm = div.firstElementChild;
        if (svgElm && svgElm.nodeName.toLowerCase() === "svg") {
            const svgClass = svgElm.getAttribute("class") || "";
            svgElm.setAttribute("class", (svgClass + " ux-icon__svg").trim());
            svgElm.removeAttribute("id");
            // remove title element to prevent a bug where the svg title was treated as the page title
            const title = svgElm.querySelector("title");
            if (title !== null) {
                title.remove();
            }
            // root element must be an svg
            // lets double check we've got valid elements
            // do not allow scripts
            if (isValid(svgElm)) {
                return div.innerHTML;
            }
        }
    }
    return "";
};
const isValid = (elm) => {
    if (elm.nodeType === 1) {
        if (elm.nodeName.toLowerCase() === "script") {
            return false;
        }
        for (let i = 0; i < elm.attributes.length; i++) {
            const attr = elm.attributes[i];
            if (typeof attr !== "undefined") {
                const val = elm.attributes[i].name;
                if (isStr(val) && val.toLowerCase().indexOf("on") === 0) {
                    return false;
                }
            }
        }
        for (let i = 0; i < elm.childNodes.length; i++) {
            if (!isValid(elm.childNodes[i])) {
                return false;
            }
        }
    }
    return true;
};

const iconContent = new Map();
const requests = new Map();
const getSvgContent = (url) => {
    // see if we already have a request for this url
    let req = requests.get(url);
    if (!req) {
        // we don't already have a request
        req = fetch(url).then((rsp) => {
            if (rsp.ok) {
                return rsp.text().then((svgContent) => {
                    iconContent.set(url, validateContent(svgContent));
                });
            }
            iconContent.set(url, "");
        });
        // cache for the same requests
        requests.set(url, req);
    }
    return req;
};

const availableIcons = [
    "arrow-down",
    "arrow-right",
    "arrow-small-right",
    "arrow-small-up",
    "cart",
    "cart-bending-tools",
    "cart-genuine-parts",
    "cart-punching-tools",
    "case-in-progress",
    "circle-filled",
    "close",
    "checkmark-rounded-thin",
    "cog",
    "crane",
    "documents",
    "fav-filled",
    "fav",
    "hourglass-circle-arrow",
    "list",
    "machine-fav",
    "machine",
    "mail-approved",
    "mail-denied",
    "order-status-package-checkmark",
    "sort",
    "tiles",
    "watchlist",
    "wrench",
    "wrench-checkmark",
    "wrench-plus",
];

const iconCss = ".ux-icon{display:inline-block;vertical-align:middle}.ux-icon__inner{width:1em;height:1em;display:block}.ux-icon__svg{width:100%;height:100%;display:block}";

/**
 * this component is heavily inspired by https://github.com/ionic-team/ionicons
 */
class Icon extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** name of icon */
        this.name = "";
        /** contains the full svg */
        this.svgContent = null;
    }
    connectedCallback() {
        this.loadIcon();
    }
    loadIcon() {
        if (this.name === "") {
            return;
        }
        if (availableIcons.indexOf(this.name) === -1) {
            if (loggedWarnings.indexOf(this.name) !== -1)
                return;
            console.warn(`Icon ${this.name} is not available in ux-icon.`);
            loggedWarnings.push(this.name);
            return;
        }
        const url = getAssetPath(`./assets/${this.name}.svg`);
        if (iconContent.has(url)) {
            // sync if it's already loaded
            this.svgContent = iconContent.get(url);
        }
        else {
            // async if it hasn't been loaded
            getSvgContent(url).then(() => (this.svgContent = iconContent.get(url)));
        }
    }
    render() {
        if (this.name === "" || this.svgContent === null) {
            return null;
        }
        return (h(Host, { class: "ux-icon" }, h("div", { class: "ux-icon__inner", innerHTML: this.svgContent })));
    }
    static get assetsDirs() { return ["assets"]; }
    static get watchers() { return {
        "name": ["loadIcon"]
    }; }
    static get style() { return iconCss; }
}
// this array holds logged warnings about unknown icons to prevent duplicate warnings
const loggedWarnings = [];

function throttle(func, timeFrame) {
    let lastTime = 0;
    return function () {
        const now = new Date().valueOf();
        if (now - lastTime >= timeFrame) {
            func();
            lastTime = now;
        }
    };
}

class InfiniteScrollSensor extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** is true after the event was fired. This prevents the event from firing again. set this to false to re-enable the event */
        this.hasFired = false;
        /** this name will also be in the event */
        this.name = "";
        this.onScroll = throttle(() => {
            if (!this.hasFired && this.sensor !== null && isInView(this.sensor)) {
                this.hasFired = true;
                this.scrolledIntoView.emit(this.name);
            }
        }, 100);
        this.scrolledIntoView = createEvent(this, "uxInfiniteScrollSensorScrolledIntoView", 7);
    }
    connectedCallback() {
        document.addEventListener("scroll", this.onScroll);
    }
    disconnectedCallback() {
        document.removeEventListener("scroll", this.onScroll);
    }
    render() {
        return h(Host, { class: "ux-infinite-scroll-sensor" });
    }
    get sensor() { return this; }
}
function isInView(el) {
    const box = el.getBoundingClientRect();
    return box.top < window.innerHeight && box.bottom >= 0;
}

const listCss = "ux-list{display:block}ux-list>ul{list-style-type:none;padding:0;margin:0}ux-list>ul>li{padding:0 15px}ux-list .ux-dropdown__item--hidden{display:none}";

const hiddenClass = "ux-dropdown__item--hidden";
class List extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** enables the search field inside the list */
        this.filterable = false;
        this.items = [];
        this.slotLabels = [];
        this.filterString = "";
        /** list element that hosts all items */
        this.ul = null;
    }
    componentDidLoad() {
        if (this.ul === null)
            return;
        [].forEach.call(this.ul.children, (child, i) => {
            const label = child.getAttribute("label");
            if (!child.matches("li")) {
                // wrap child in li element
                const li = document.createElement("li");
                child.parentNode.insertBefore(li, child);
                li.appendChild(child);
            }
            this.slotLabels[i] = label;
        });
    }
    /** returns true when item should be shown according to the filter */
    isInFilter(itemName) {
        return (this.filterString.length === 0 ||
            itemName.toLowerCase().indexOf(this.filterString) !== -1);
    }
    /** set the Content from outside */
    async setFilterValues(filterValues) {
        this.items = filterValues;
    }
    onFilterChange(event) {
        this.filterString = event.target.value.toLowerCase();
        if (this.items.length > 0)
            return;
        this.slotLabels.forEach((label, i) => {
            const element = this.ul.children[i];
            if (this.isInFilter(label)) {
                element.classList.remove(hiddenClass);
            }
            else {
                element.classList.add(hiddenClass);
            }
        });
    }
    render() {
        const filterInput = this.filterable && (h("div", { class: "ux-list__filter" }, h("input", { class: "ux-list__filter-input ux-input", type: "text", placeholder: "Search", onKeyUp: this.onFilterChange.bind(this) })));
        const hasItems = this.items.length > 0;
        return (h(Host, null, filterInput, h("ul", { ref: (el) => (this.ul = el), class: "ux-dropdown__list" }, h("slot", null), hasItems &&
            this.items.map((item) => (h("li", { class: {
                    [hiddenClass]: !this.isInFilter(item.label),
                } }, h("ux-checkbox-list-item", { label: item.label, value: item.value })))))));
    }
    get domNode() { return this; }
    static get style() { return listCss; }
}

const getValidatedValue = (newValue, oldValue, max, min) => {
    const newNumber = +newValue;
    if (isNaN(newNumber)) {
        return oldValue;
    }
    if (!isNaN(max) && newNumber > max) {
        return max;
    }
    if (!isNaN(min) && newNumber < min) {
        return min;
    }
    return Math.round(newNumber);
};
const calculateValue = (type, value, increment, max, min) => {
    const factor = type === "decrement" ? -1 : 1;
    const newValue = value + factor * increment;
    return getValidatedValue(newValue, value, max, min);
};
const getNumberValue = (string) => {
    const number = string === "" ? NaN : +string;
    return number;
};

const numberInputCss = ".ux-number-input{display:-ms-flexbox;display:flex;border:1px solid black}.ux-number-input__input[type=number]{text-align:center;padding:12px 10px;-ms-flex:1 1 0px;flex:1 1 0;width:auto;min-width:45px;border-radius:0;border:1px solid black;border-top-width:0;border-bottom-width:0;appearance:none;-webkit-appearance:none;-moz-appearance:textfield}.ux-number-input__input[type=number]::-webkit-outer-spin-button,.ux-number-input__input[type=number]::-webkit-inner-spin-button{-webkit-appearance:none;appearance:none}.ux-number-input__btn{-webkit-appearance:none;-moz-appearance:none;appearance:none;border:0;background:#e7e7e7;min-width:45px;-ms-flex:0 1 45px;flex:0 1 45px;text-align:center;border-radius:0}";

class NumberInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** name attribute for the input */
        this.name = "";
        /** initial value for the input */
        this.initialValue = "0";
        /** size of increment/decrement for the plus/minus button */
        this.step = "1";
        /** max value */
        this.max = "";
        /** min value */
        this.min = "";
    }
    componentWillLoad() {
        const { initialValue } = this;
        const initialNumber = +initialValue;
        if (!isNaN(initialNumber)) {
            this.value = initialNumber;
        }
        this.setNumbers();
    }
    setNumbers() {
        const { max, min, step } = this;
        this.minValue = getNumberValue(min);
        this.maxValue = getNumberValue(max);
        const stepValue = getNumberValue(step);
        this.stepValue = isNaN(stepValue) ? 1 : stepValue;
    }
    handlePlus() {
        this.changeValue("increment");
    }
    handleMinus() {
        this.changeValue("decrement");
    }
    changeValue(type = "increment") {
        const { stepValue, maxValue, minValue, value } = this;
        this.value = calculateValue(type, value, stepValue, maxValue, minValue);
    }
    onChange(event) {
        const { maxValue, minValue } = this;
        const { value } = event.target;
        this.value = getValidatedValue(value, this.value, maxValue, minValue);
        event.target.value = this.value;
    }
    render() {
        const baseClass = "ux-number-input";
        const { name, max, min, stepValue, value } = this;
        return (h(Host, { class: baseClass }, h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handleMinus() }, "\u2013"), h("input", { class: `${baseClass}__input`, name: name, step: stepValue.toString(), type: "number", max: max, min: min, value: value, onInput: (event) => this.onChange(event) }), h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handlePlus() }, "+")));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "min": ["setNumbers"],
        "max": ["setNumbers"],
        "step": ["setNumbers"]
    }; }
    static get style() { return numberInputCss; }
}

function scrollToTopFallBack() {
    if (window.scrollY !== 0) {
        setTimeout(() => {
            window.scroll(0, window.scrollY - 40);
            scrollToTopFallBack();
        }, 20);
    }
}
function scrollToTop() {
    let behaviorSupported = false;
    try {
        window.scroll({
            // @ts-ignore
            get behavior() {
                behaviorSupported = true;
                return "smooth";
            },
        });
    }
    catch (err) {
        console.error(err);
    }
    if (behaviorSupported) {
        window.scroll({
            top: 0,
            behavior: "smooth",
        });
    }
    else {
        scrollToTopFallBack();
    }
}

const scrollToTopButtonCss = ".ux-scroll-to-top-button{display:inline-block;min-height:44px;min-width:44px;padding:9px 12px 7px}.ux-scroll-to-top-button .ux-icon{font-size:18px}.ux-scroll-to-top-button:hover svg{fill:#fff}";

class ScrollToTopButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    render() {
        return (h("button", { class: "ux-scroll-to-top-button ux-button", onClick: () => scrollToTop() }, h("ux-icon", { name: "arrow-small-up" })));
    }
    static get style() { return scrollToTopButtonCss; }
}

const selectCss = ".ux-select{display:inline-block}";

class Select extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** input name which is used as identifier in forms  */
        this.name = "";
        this.changeEventDetail = createEvent(this, "uxSelectChange", 7);
    }
    /** function to emit new active option value */
    selectChange(newValue) {
        this.changeEventDetail.emit(newValue.value);
    }
    render() {
        return (h(Host, { class: "ux-select" }, h("ux-icon", { class: "ux-select__icon", name: "arrow-down" }), h("select", { class: "ux-select__select", onChange: (e) => this.selectChange(e.target), name: this.name }, h("slot", null))));
    }
    static get style() { return selectCss; }
}

const tabCss = ".ux-tab{display:none}.ux-tab.is-active{display:block}";

class Tab extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Sets the name for the corresponding tab-button */
        this.name = "";
        /** Sets ID for Tab */
        this.tabId = "";
        /** Boolean to indicate active tab */
        this.active = false;
    }
    setActiveTab(event) {
        this.active = event.detail === this.tabId;
    }
    render() {
        return (h(Host, { class: `ux-tab ${this.active ? "is-active" : ""}` }, h("slot", null)));
    }
    get domNode() { return this; }
    static get style() { return tabCss; }
}

const tabButtonCss = ".ux-tab-button{display:-ms-inline-flexbox;display:inline-flex}.ux-tab-button+.ux-tab-button{margin-left:5px}.ux-tab-button__label{color:#131313;cursor:pointer;display:block;padding:8px 10px;position:relative;-webkit-transition:color 250ms ease-in-out;transition:color 250ms ease-in-out}.ux-tab-button__label::after{background-color:#bbd03a;content:\"\";display:block;height:3px;position:absolute;bottom:0;left:0;-webkit-transform:scaleX(0);transform:scaleX(0);-webkit-transform-origin:center;transform-origin:center;-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:100%}.ux-tab-button__label:hover{color:#595959}.ux-tab-button__label:hover::after{-webkit-transform:scaleX(1);transform:scaleX(1)}.ux-tab-button.is-active .ux-tab-button__label::after{-webkit-transform:scaleX(1);transform:scaleX(1)}";

class TabButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Displays the label of the tab */
        this.name = "";
        /** Contains this tabs ID */
        this.tabId = "";
        this.active = false;
    }
    componentWillLoad() {
        this.active = this.activeTab === this.tabId;
    }
    render() {
        return (h(Host, { class: `ux-tab-button ${this.active ? "is-active" : ""}` }, h("div", { class: "ux-tab-button__label", id: this.tabId }, this.name)));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "activeTab": ["componentWillLoad"]
    }; }
    static get style() { return tabButtonCss; }
}

const tabContainerCss = ".ux-tab-container{display:block}.ux-tab-container__tab-header{-ms-flex-pack:start;justify-content:flex-start;border-bottom:1px solid #c4c4c4;display:-ms-flexbox;display:flex}.ux-tab-container__tab-body{padding-top:15px}";

class TabContainer extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** prop which holds the active tab id */
        this.activeTabId = "";
        /** when this is true, the tab navigation will not be displayed */
        this.noNavigation = false;
        this.activeTabEvent = createEvent(this, "uxActiveTabSet", 7);
    }
    /** id of the tab which will be active */
    async setActiveTab(id) {
        this.activeTabId = id;
        this.activeTabEvent.emit(id);
    }
    componentWillLoad() {
        var _a;
        const children = Array.from(this.domNode.children);
        this.children = children;
        if (this.activeTabId !== "") {
            this.setActiveTab(this.activeTabId);
        }
        else {
            this.setActiveTab((_a = this.children[0]) === null || _a === void 0 ? void 0 : _a.tabId);
        }
    }
    render() {
        return (h(Host, { class: "ux-tab-container" }, !this.noNavigation && (h("div", { class: "ux-tab-container__tab-header" }, this.children.map((tab) => (h("ux-tab-button", { onClick: () => this.setActiveTab(tab.tabId), name: tab.name, tabId: tab.tabId, activeTab: this.activeTabId }))))), h("div", { class: "ux-tab-container__tab-body" }, h("slot", null))));
    }
    get domNode() { return this; }
    static get style() { return tabContainerCss; }
}

const tabSwitcherCss = ".ux-tab-switcher.ux-button--icon-only .ux-icon{-webkit-transform:translateY(-50%);transform:translateY(-50%);margin-top:50%}";

applyPolyfills();
class TabSwitcher extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** identifier of the targeted tab */
        this.tabId = "";
        this.tabContainer = null;
        /** shows the button as activated - this should be in sync with the tab */
        this.active = false;
    }
    componentWillLoad() {
        if (this.tabId === "")
            return;
        this.tabContainer = document
            .querySelector(`ux-tab[tab-id=${this.tabId}]`)
            .closest("ux-tab-container");
        this.active = this.tabContainer.activeTabId === this.tabId;
        this.tabContainer.addEventListener("uxActiveTabSet", (e) => {
            this.active = e.detail === this.tabId;
        });
    }
    render() {
        return (h(Host, { class: `ux-tab-switcher ux-button ux-button--${this.active ? "toggle-active" : "toggle"}`, onClick: () => {
                if (this.tabContainer === null || this.tabId === "")
                    return;
                this.tabContainer.setActiveTab(this.tabId);
            } }, h("slot", null)));
    }
    static get style() { return tabSwitcherCss; }
}

/** Avoid running the same function twice within the specified timeframe. */
const debounce = (func, wait, immediate = false) => {
    let timeout;
    return function () {
        var context = this, args = arguments;
        clearTimeout(timeout);
        timeout = setTimeout(() => {
            timeout = null;
            if (!immediate)
                func.apply(context, args);
        }, wait);
        if (immediate && !timeout)
            func.apply(context, args);
    };
};

const tableCss = ".ux-table{display:block;position:relative}.ux-table table{border-collapse:collapse;border-spacing:0;margin:0 auto;width:-webkit-max-content;width:-moz-max-content;width:max-content}.ux-table td,.ux-table th{padding:30px;text-align:left;white-space:normal}.ux-table td{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;font-size:16px;text-transform:none}.ux-table th{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;font-size:13px;color:#fff;text-transform:uppercase;background-color:#899fb2}.ux-table thead tr{background-color:#899fb2}.ux-table tr:nth-child(odd) td{background-color:#eaedf2}.ux-table tr:nth-child(even) td{background-color:#fff}.ux-table__inner{overflow-x:auto;height:auto}.ux-table__inner::before,.ux-table__inner::after{content:\"\";opacity:0;position:absolute;z-index:1;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%);width:50px;height:calc(100% + 1px);pointer-events:none;-webkit-transition:opacity 0.5s ease;transition:opacity 0.5s ease}.ux-table__inner::before{background:-webkit-gradient(linear, right top, left top, color-stop(0, rgba(255, 255, 255, 0)), to(rgba(0, 0, 0, 0.2)));background:linear-gradient(to left, rgba(255, 255, 255, 0) 0, rgba(0, 0, 0, 0.2) 100%)}.ux-table__inner::after{right:0;background:-webkit-gradient(linear, left top, right top, color-stop(0, rgba(255, 255, 255, 0.1)), to(#fff));background:linear-gradient(to right, rgba(255, 255, 255, 0.1) 0, #fff 100%)}.ux-table--has-left-shadow .ux-table__inner::before{opacity:1}.ux-table--has-right-shadow .ux-table__inner::after{opacity:1}.ux-table--full-width table{min-width:100%}.ux-table--is-fixed table{min-width:auto}";

applyPolyfills();
class Table extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** zero-based index of the column that should be fixed on smaller viewports - defaults to the first col */
        this.fixedColIndex = 0;
        /** maximum number of pixels that the fixed column is allowed to be wide */
        this.maxFixedColWidth = 250;
        /** the table should always be at least 100% wide */
        this.fullWidth = false;
        /** the table should sort its static data by itself. Do not use this if the data needs to be sorted by some logic (i.e. via an API) */
        this.sortable = false;
        /** is true when the table is horizontally scrollable (has a fixed col) */
        this.isFixed = false;
        /** width of the fixed col */
        this.fixedColWidth = 250;
        /** the left shadow is visible */
        this.leftShadow = false;
        /** the right shadow is visible */
        this.rightShadow = false;
        this.contentObserver = new MutationObserver(debounce(() => this.onContentChange(), 100));
        this.onResize = throttle(() => this.calculateTableState(), 300);
        this.onScroll = throttle(() => this.calculateShadows(), 10);
    }
    connectedCallback() {
        this.uniqueId = `ux-table-id-${idCounter++}`;
        this.table = this.element.querySelector("table");
        window.addEventListener("resize", this.onResize);
    }
    componentDidLoad() {
        this.calculateFixedColWidth();
        this.calculateTableState();
        this.calculateShadows();
        this.syncRowHeight();
        this.contentObserver.observe(this.innerDiv, {
            childList: true,
            subtree: true,
        });
    }
    disconnectedCallback() {
        window.removeEventListener("resize", this.onResize);
        this.contentObserver.disconnect();
    }
    onContentChange() {
        this.syncRowHeight();
        this.calculateFixedColWidth();
        this.calculateTableState();
        this.calculateShadows();
    }
    calculateTableState() {
        const containerWidth = this.element.getBoundingClientRect().width;
        const tableRect = this.table.getBoundingClientRect();
        const tableWidth = tableRect.width + (this.isFixed ? this.fixedColWidth : 0);
        this.isFixed = containerWidth < tableWidth;
    }
    calculateFixedColWidth() {
        const { table, fixedColIndex, maxFixedColWidth } = this;
        const fixedCells = table.querySelectorAll(`td:nth-child(${fixedColIndex + 1})
            ,th:nth-child(${fixedColIndex + 1})`);
        const fixedCellsArray = [].slice.call(fixedCells);
        let width = 0;
        // we only calculate the width for the first 50 items to prevent that bigger tables get slow.
        fixedCellsArray
            .slice(0, 50)
            .forEach((cell) => {
            const cellWidth = cell.offsetWidth;
            width = cellWidth > width ? cellWidth : width;
        });
        this.fixedColWidth =
            width > maxFixedColWidth ? maxFixedColWidth : width;
    }
    calculateShadows() {
        const scrollLeft = this.innerDiv.scrollLeft;
        const containerWidth = this.innerDiv.getBoundingClientRect().width;
        const tableWidth = this.table.getBoundingClientRect().width +
            (this.isFixed ? this.fixedColWidth : 0);
        this.leftShadow = this.isFixed && scrollLeft > 0;
        this.rightShadow = scrollLeft + containerWidth < tableWidth;
    }
    /** the height of multi-line cells might differ from the fixed cell, so we need to sync it to prevent gaps */
    syncRowHeight() {
        const rows = this.table.querySelectorAll("tr");
        [].forEach.call(rows, (row) => {
            const rowHeight = row.getBoundingClientRect().height;
            const fixedCell = row.querySelector(`th:nth-child(${this.fixedColIndex + 1}),td:nth-child(${this.fixedColIndex + 1})`);
            const fixedCellHeight = fixedCell.getBoundingClientRect().height;
            const height = Math.max(rowHeight, fixedCellHeight);
            row.style.height = `${height}px`;
            fixedCell.style.height = `${height}px`;
        });
    }
    sortRows(e) {
        if (!this.sortable)
            return;
        const sorter = e.target;
        const th = sorter.closest("th");
        const titleRow = th.parentElement;
        const colIndex = [].indexOf.call(titleRow.children, th);
        const table = th.closest("table");
        const sortAttr = "data-sort";
        const getCellValue = (tr, idx) => tr.children[idx].hasAttribute(sortAttr)
            ? tr.children[idx].getAttribute(sortAttr)
            : tr.children[idx].textContent;
        const comparer = (idx, asc) => (a, b) => getCellValue(asc ? a : b, idx).localeCompare(getCellValue(asc ? b : a, idx));
        [].slice
            .call(table.querySelectorAll(`tr`))
            .filter((tr) => !tr.isSameNode(titleRow))
            .sort(comparer(colIndex, sorter.sortedDirection === "asc"))
            .forEach((tr) => table.appendChild(tr));
    }
    render() {
        const baseClass = "ux-table";
        const fixedClass = `${baseClass}--is-fixed`;
        const { uniqueId, isFixed, fixedColIndex, fixedColWidth, maxFixedColWidth, leftShadow, rightShadow, fullWidth, } = this;
        const fixedCol = fixedColIndex + 1; // CSS selectors work with an 1-based index
        return (h(Host, { class: {
                [baseClass]: true,
                [fixedClass]: isFixed,
                [`${baseClass}--has-left-shadow`]: leftShadow,
                [`${baseClass}--has-right-shadow`]: rightShadow,
                [`${baseClass}--full-width`]: fullWidth,
            } }, h("style", null, `
                    #${uniqueId} th:nth-child(${fixedCol}),
                    #${uniqueId} td:nth-child(${fixedCol}) {
                        max-width: ${maxFixedColWidth}px;
                    }
                    .${fixedClass} #${uniqueId} th:nth-child(${fixedCol}),
                    .${fixedClass} #${uniqueId} td:nth-child(${fixedCol}) {
                        position: absolute;
                        left: 0;
                        width: ${fixedColWidth}px;
                    }
                    .${fixedClass} #${uniqueId} table {
                        margin-left: ${fixedColWidth}px;
                    }
                    #${uniqueId}:before {
                        left: ${fixedColWidth}px;
                    }
                `), h("div", { class: `${baseClass}__inner`, ref: (el) => (this.innerDiv = el), onScroll: () => this.onScroll(), id: uniqueId }, h("slot", null))));
    }
    get element() { return this; }
    static get watchers() { return {
        "isFixed": ["calculateShadows", "syncRowHeight"]
    }; }
    static get style() { return tableCss; }
}
/** this variable is incremented by each instance */
let idCounter = 0;

const tableSortCss = ".ux-table-sort{cursor:pointer}.ux-table-sort[sorted-direction=asc]{border-bottom:solid 1px}.ux-table-sort[sorted-direction=asc] .ux-icon__sort-down{fill:#bbd03a}.ux-table-sort[sorted-direction=desc]{border-bottom:solid 1px}.ux-table-sort[sorted-direction=desc] .ux-icon__sort-up{fill:#bbd03a}.ux-table-sort__icon{font-size:12px;fill:currentColor}";

applyPolyfills();
class TableSort extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** indicates in which direction the data is already sorted. This has to be empty when it is not sorted yet. Setting this does not trigger the sorting event. Clicking the button will update this attribute. */
        this.sortedDirection = "";
        this.sortEvent = createEvent(this, "uxTableSort", 7);
    }
    sort() {
        this.sortedDirection = this.sortedDirection !== "asc" ? "asc" : "desc";
        const name = this.sortedDirection === "asc" ? this.ascName : this.descName;
        this.sortEvent.emit(name);
        const allSorters = this.domElement
            .closest("tr")
            .querySelectorAll("ux-table-sort");
        [].forEach.call(allSorters, (element) => {
            if (element.isEqualNode(this.domElement))
                return;
            element.sortedDirection = "";
        });
    }
    render() {
        const baseClass = "ux-table-sort";
        return (h(Host, { class: baseClass, onClick: () => this.sort() }, h("slot", null), "\u00A0", h("ux-icon", { class: `${baseClass}__icon`, name: "sort" })));
    }
    get domElement() { return this; }
    static get style() { return tableSortCss; }
}

class Tag extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.remove = createEvent(this, "uxRemove", 7);
    }
    removeTag() {
        this.remove.emit(this.reference);
        this.domNode.remove();
    }
    render() {
        return (h(Host, { class: "ux-tag", onClick: (e) => {
                e.preventDefault();
                this.removeTag();
            } }, h("span", { class: "ux-tag__label" }, h("slot", null)), h("ux-icon", { name: "close" })));
    }
    get domNode() { return this; }
}

const toggleButtonCss = ".ux-toggle-button{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:inline-block;padding:0 5px;color:#131313}.ux-toggle-button--on{color:#bbd03a}.ux-toggle-button--has-error{color:#ff0201}.ux-toggle-button .ux-icon{fill:currentColor}";

class ToggleButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** is the toggle on or off */
        this.on = false;
        /** this id is used to identify similar toggleButtons to synchronise them */
        this.syncId = "";
        /** optional url to be called when the item should be toggled */
        this.toggleUrl = "";
        /** optional url to be called when the item should be untoggled (-> off), can be left empty if it is identical to toggleUrl */
        this.untoggleUrl = "";
        /** text to show on toggle button in "on" state (if used with icon it will be the title attribute) */
        this.textOn = "";
        /** text to show on toggle button in "off" state (if used with icon it will be the title attribute) */
        this.textOff = "";
        /** name of icon to show when in state "on" */
        this.iconOn = "";
        /** name of icon to show when in state "off" */
        this.iconOff = "";
        /** the component sets this to true when an error occurs while communicating with the API */
        this.error = false;
        this.didToggle = createEvent(this, "uxToggle", 7);
        this.toggleFailed = createEvent(this, "uxToggleFailed", 7);
    }
    toggle() {
        const { on } = this;
        this.on = !on;
        this.error = false;
        this.waitForToggle(() => {
            this.didToggle.emit(this.on);
            this.syncOtherButtons();
        }, () => {
            this.on = on;
            this.error = true;
            this.toggleFailed.emit(this.on);
        });
    }
    syncOtherButtons() {
        const { syncId, on } = this;
        if (syncId === "")
            return;
        const sameButtons = document.querySelectorAll(`ux-toggle-button[sync-id=${syncId}]`);
        [].forEach.call(sameButtons, (button) => {
            button.on = on;
        });
    }
    waitForToggle(callback, error) {
        const { toggleUrl, untoggleUrl, on } = this;
        if (toggleUrl === "") {
            callback();
            return;
        }
        const url = on && untoggleUrl !== "" ? untoggleUrl : toggleUrl;
        api(url).then(callback).catch(error);
    }
    render() {
        const baseClass = "ux-toggle-button";
        const { on, textOff, textOn, iconOff, iconOn, error } = this;
        const text = on ? textOn : textOff;
        const hasIcons = iconOn !== "" && iconOff !== "";
        return (h(Host, { class: {
                [baseClass]: true,
                "ux-toggle-button--on": on,
                "ux-toggle-button--off": !on,
                "ux-toggle-button--has-error": error,
            }, onClick: (e) => {
                e.preventDefault();
                this.toggle();
            }, title: hasIcons ? text : "" }, !hasIcons && text, hasIcons && h("ux-icon", { name: on ? iconOn : iconOff })));
    }
    static get style() { return toggleButtonCss; }
}

const UxAutosuggestInput = /*@__PURE__*/proxyCustomElement(AutosuggestInput, [0,"ux-autosuggest-input",{"placeholder":[1],"name":[1],"inputId":[1,"input-id"],"label":[1],"url":[1],"suggestions":[32],"input":[32],"isHidden":[32],"id":[32]}]);
const UxAutosuggestItem = /*@__PURE__*/proxyCustomElement(AutosuggestItem, [0,"ux-autosuggest-item",{"input":[1],"text":[1],"subline":[1],"image":[1]}]);
const UxCheckbox = /*@__PURE__*/proxyCustomElement(Checkbox, [4,"ux-checkbox",{"value":[1],"label":[1],"name":[1],"checked":[4],"disabled":[4]}]);
const UxCheckboxListItem = /*@__PURE__*/proxyCustomElement(CheckboxListItem, [4,"ux-checkbox-list-item",{"value":[1],"label":[1],"name":[1],"checked":[4],"disabled":[4]}]);
const UxCopyToClipboard = /*@__PURE__*/proxyCustomElement(CopyToClipboard, [0,"ux-copy-to-clipboard",{"textToCopy":[513,"text-to-copy"],"clickToCopyIcon":[1,"click-to-copy-icon"],"clickToCopyIconSuccessful":[1,"click-to-copy-icon-successful"],"clickToCopyMessage":[1,"click-to-copy-message"],"clickToCopyMessageSuccessful":[1,"click-to-copy-message-successful"],"hideTextToCopy":[4,"hide-text-to-copy"],"wasSuccessful":[32]}]);
const UxDataIngest = /*@__PURE__*/proxyCustomElement(DataIngest, [4,"ux-data-ingest"]);
const UxDateTime = /*@__PURE__*/proxyCustomElement(DateTime, [0,"ux-date-time",{"utc":[1],"format":[1],"formattedDateTime":[32]}]);
const UxDropdown = /*@__PURE__*/proxyCustomElement(Dropdown, [4,"ux-dropdown",{"label":[513],"name":[513],"filterable":[516],"isOpen":[32]},[[32,"click","handleBodyClick"]]]);
const UxFilter = /*@__PURE__*/proxyCustomElement(Filter, [4,"ux-filter",{"endpoint":[513],"filterValues":[32]},[[0,"uxRemove","tagRemovedHandler"]]]);
const UxIcon = /*@__PURE__*/proxyCustomElement(Icon, [0,"ux-icon",{"name":[513],"svgContent":[32]}]);
const UxInfiniteScrollSensor = /*@__PURE__*/proxyCustomElement(InfiniteScrollSensor, [0,"ux-infinite-scroll-sensor",{"hasFired":[516,"has-fired"],"name":[513]}]);
const UxList = /*@__PURE__*/proxyCustomElement(List, [4,"ux-list",{"filterable":[516],"items":[32],"slotLabels":[32],"filterString":[32]}]);
const UxNumberInput = /*@__PURE__*/proxyCustomElement(NumberInput, [0,"ux-number-input",{"name":[1],"initialValue":[1,"initial-value"],"step":[1],"max":[1],"min":[1],"value":[32],"minValue":[32],"maxValue":[32],"stepValue":[32]}]);
const UxScrollToTopButton = /*@__PURE__*/proxyCustomElement(ScrollToTopButton, [0,"ux-scroll-to-top-button"]);
const UxSelect = /*@__PURE__*/proxyCustomElement(Select, [4,"ux-select",{"name":[513]}]);
const UxTab = /*@__PURE__*/proxyCustomElement(Tab, [4,"ux-tab",{"name":[513],"tabId":[513,"tab-id"],"active":[32]},[[16,"uxActiveTabSet","setActiveTab"]]]);
const UxTabButton = /*@__PURE__*/proxyCustomElement(TabButton, [0,"ux-tab-button",{"name":[513],"activeTab":[513,"active-tab"],"tabId":[513,"tab-id"],"active":[32]}]);
const UxTabContainer = /*@__PURE__*/proxyCustomElement(TabContainer, [4,"ux-tab-container",{"activeTabId":[513,"active-tab-id"],"noNavigation":[4,"no-navigation"]}]);
const UxTabSwitcher = /*@__PURE__*/proxyCustomElement(TabSwitcher, [4,"ux-tab-switcher",{"tabId":[1,"tab-id"],"active":[32]}]);
const UxTable = /*@__PURE__*/proxyCustomElement(Table, [4,"ux-table",{"fixedColIndex":[2,"fixed-col-index"],"maxFixedColWidth":[2,"max-fixed-col-width"],"fullWidth":[4,"full-width"],"sortable":[4],"isFixed":[32],"fixedColWidth":[32],"leftShadow":[32],"rightShadow":[32],"uniqueId":[32]},[[0,"uxTableSort","sortRows"]]]);
const UxTableSort = /*@__PURE__*/proxyCustomElement(TableSort, [4,"ux-table-sort",{"ascName":[1,"asc-name"],"descName":[1,"desc-name"],"sortedDirection":[513,"sorted-direction"]}]);
const UxTag = /*@__PURE__*/proxyCustomElement(Tag, [4,"ux-tag",{"reference":[513]}]);
const UxToggleButton = /*@__PURE__*/proxyCustomElement(ToggleButton, [0,"ux-toggle-button",{"on":[1540],"syncId":[1,"sync-id"],"toggleUrl":[1,"toggle-url"],"untoggleUrl":[1,"untoggle-url"],"textOn":[1,"text-on"],"textOff":[1,"text-off"],"iconOn":[1,"icon-on"],"iconOff":[1,"icon-off"],"error":[1540]}]);
const defineCustomElements = () => {
  [
  UxAutosuggestInput,
  UxAutosuggestItem,
  UxCheckbox,
  UxCheckboxListItem,
  UxCopyToClipboard,
  UxDataIngest,
  UxDateTime,
  UxDropdown,
  UxFilter,
  UxIcon,
  UxInfiniteScrollSensor,
  UxList,
  UxNumberInput,
  UxScrollToTopButton,
  UxSelect,
  UxTab,
  UxTabButton,
  UxTabContainer,
  UxTabSwitcher,
  UxTable,
  UxTableSort,
  UxTag,
  UxToggleButton
  ].forEach(cmp => customElements.define(cmp.is, cmp));
};

export { UxAutosuggestInput, UxAutosuggestItem, UxCheckbox, UxCheckboxListItem, UxCopyToClipboard, UxDataIngest, UxDateTime, UxDropdown, UxFilter, UxIcon, UxInfiniteScrollSensor, UxList, UxNumberInput, UxScrollToTopButton, UxSelect, UxTab, UxTabButton, UxTabContainer, UxTabSwitcher, UxTable, UxTableSort, UxTag, UxToggleButton, defineCustomElements };
